# Table of Contents

- [tutorial-managing-it-risks-associated-with-data-center-and-server-locations](<./tutorial-managing-it-risks-associated-with-data-center-and-server-locations.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Tutorial: Managing IT Risks Associated with Data Center and Server Locations](<./Tutorial-Managing-IT-Risks-Associated-with-Data-Center-and-Server-Locations.md>)
  - [Overview](<./Tutorial-Managing-IT-Risks-Associated-with-Data-Center-and-Server-Locations/Overview.md>)
  - [Prerequisite: Build an Application Inventory in SAP LeanIX](<./Tutorial-Managing-IT-Risks-Associated-with-Data-Center-and-Server-Locations/Prerequisite-Build-an-Application-Inventory-in-SAP-LeanIX.md>)
  - [Step 1: Build an IT Component Repository](<./Tutorial-Managing-IT-Risks-Associated-with-Data-Center-and-Server-Locations/Step-1-Build-an-IT-Component-Repository.md>)
  - [Step 2: Add the Software Versions and Assess Risk and Suitability](<./Tutorial-Managing-IT-Risks-Associated-with-Data-Center-and-Server-Locations/Step-2-Add-the-Software-Versions-and-Assess-Risk-and-Suitability.md>)
  - [Step 3: Import Data Center and Server Location Information](<./Tutorial-Managing-IT-Risks-Associated-with-Data-Center-and-Server-Locations/Step-3-Import-Data-Center-and-Server-Location-Information.md>)
  - [Step 4: Link IT Components to Application Fact Sheets](<./Tutorial-Managing-IT-Risks-Associated-with-Data-Center-and-Server-Locations/Step-4-Link-IT-Components-to-Application-Fact-Sheets.md>)
  - [Step 5: Analyze and Mitigate Risks](<./Tutorial-Managing-IT-Risks-Associated-with-Data-Center-and-Server-Locations/Step-5-Analyze-and-Mitigate-Risks.md>)
  - [Was this page helpful?](<./Tutorial-Managing-IT-Risks-Associated-with-Data-Center-and-Server-Locations/Was-this-page-helpful.md>)
